"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const marked_1 = __importDefault(require("marked"));
const nbformat_1 = require("./nbformat");
class EmptyRenderer extends marked_1.default.Renderer {
    constructor(options) {
        super(options);
        for (const prop in this) {
            if (this[prop] instanceof Function) {
                this[prop] = () => '';
            }
        }
    }
}
class MainTitleRenderer extends EmptyRenderer {
    constructor() {
        super(...arguments);
        this._titleFound = false;
    }
    heading(_text, level, raw, _slugger) {
        if (level === 1 && !this._titleFound) {
            this._titleFound = true;
            return raw;
        }
        return '';
    }
}
/**
 * Returns title of the given *notebook*, or an empty string if not found.
 *
 * If the title is not present in the notebook's metadata and the first cell is
 * a Markdown cell, it parses it and returns the first level 1 heading.
 */
exports.default = (notebook) => {
    if (notebook.metadata.title) {
        return notebook.metadata.title;
    }
    if (notebook.cells.length > 0 && notebook.cells[0].cell_type === nbformat_1.CellType.Markdown) {
        const source = notebook.cells[0].source;
        const markup = Array.isArray(source) ? source.join('') : source;
        return marked_1.default.parse(markup, { renderer: new MainTitleRenderer() });
    }
    return '';
};
//# sourceMappingURL=readNotebookTitle.js.map