"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const htmlEntities = {
    '&': '&amp;',
    '<': '&lt;',
    '>': '&gt;',
};
/**
 * Creates a "callable object" with the given properties. In fact, it creates
 * a function that calls `obj[funcName]` and copies all the enumerable
 * properties of the *template* to the created function.
 *
 * @param {string} funcName Name of the function property of the *template*.
 * @param {Object} template The source object from which to copy enumerable properties.
 * @return A function with all enumerable properties of the *template*.
 */
function callableObject(funcName, template) {
    const fn = function (...args) {
        return template[funcName](...args);
    };
    return Object.assign(fn, template);
}
exports.callableObject = callableObject;
/**
 * Escapes characters with special meaning in HTML with the corresponding
 * HTML entities.
 */
function escapeHTML(str) {
    return str.replace(/[&<>]/g, c => htmlEntities[c]);
}
exports.escapeHTML = escapeHTML;
/**
 * A function that does nothing but return the parameter supplied to it.
 */
exports.identity = (x, ..._rest) => x;
//# sourceMappingURL=utils.js.map